package com.yun.task.controller;

import com.alibaba.fastjson.JSONObject;


import com.bwie.common.domain.*;
import com.bwie.common.result.Result;
import com.yun.task.service.TaskService;
import lombok.Data;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.xml.soap.Node;
import java.util.List;
import java.util.Map;

/**
 * @author Dunzhida
 * data 2023/7/27 16:08
 * fileName TaskController
 */
@RequestMapping("city")
@RestController
@Log4j2
public class TaskController {
    @Autowired
    private TaskService taskService;
    @Autowired
    private HttpServletRequest request;

    /*
    * 方法名: findBydatabase
    * 查询所有数据库
    * 参数:无
    * 请求方法:post
    * 返回结果:string的集合
    * */

    @PostMapping("/findBydatabase")
    public Result<List<String>> findBydatabase(){
        log.info("功能名称，查询所有数据库，请求URI：{}，请求方式：{}",request.getRequestURI(),request.getMethod());
        List<String> list=taskService.findBydatabase();
        System.out.println(list);
        Result<List<String>> result=Result.success(list);
        log.info("功能名称，查询所有数据库，请求URI：{}，请求方式：{}，响应结果：{}",request.getRequestURI(),request.getMethod(), JSONObject.toJSONString(result));
        return result;
    }


    /*
     * 方法名: findByTable
     * 根据数据库查询表
     * 参数: 路径传参 String  database 数据库的名称
     * 请求方法:post
     * 返回结果:string的集合
     * */

    @PostMapping("/findByTable/{database}")
    public Result<List<String>> findByTable(@PathVariable String database){
        log.info("功能名称，根据数据库名称查询数据表，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),database);
        List<String> list=taskService.findByTable(database);
        System.out.println(list);
        Result<List<String>> result=Result.success(list);
        log.info("功能名称，根据数据库名称查询数据表，请求URI：{}，请求方式：{}，响应结果：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }
    /*
    *
    * 方法名:  findByField
    * 根据表查询表字段
    * 参数: 路径传参 String  database (数据库名称)
    *      路径传参 String  datatable (表名称)
    * 请求方法:post
    * 返回结果:Mysql对象list集合
    * */

    @PostMapping("/findByField/{database}/{datatable}")
    public Result<List<Mysql>> findByField(@PathVariable String datatable, @PathVariable String database){
        log.info("功能名称，根据数据表名称查询字段，请求URI：{}，请求方式：{}，请求参数：{}{}",request.getRequestURI(),request.getMethod(),database,datatable);
        List<Mysql> list=taskService.findByField(datatable,database);
        System.out.println(list);
        Result<List<Mysql>> result=Result.success(list);
        log.info("功能名称，根据数据表名称查询字段，请求URI：{}，请求方式：{}，响应结果：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }
    /**
     * 方法名: createMiddle
     * 进入配置自动创建配置表
     * 参数: RequestBody Config  配置实体类
     *  请求方法:post
     */
    @PostMapping("/createMiddle")
    public Result createMiddle(@RequestBody Config config){
        log.info("功能名称，进入配置自动创建配置表，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(), JSONObject.toJSONString(config));
        taskService.createMiddle(config);
        System.out.println(config.getConfigId());
        Result result=Result.success(config.getConfigId());
        log.info("功能名称，进入配置自动创建配置表，请求URI：{}，请求方式：{}，响应结果：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    /*
     * 方法名: addImport
     *  添加第一个输入主表节点信息
     * 参数: NodeOne 对象
     * 请求方法:post
     * */

    @PostMapping("/addImport")
    public Result addImport(@RequestBody NodeOne NodeOne){
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(NodeOne));
        taskService.addImport(NodeOne);
        Result result=Result.success();
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }
    /*
     * 添加第二个输入副表节点信息
     * 参数: nodeTwo 对象
     * 请求方法:post
     * */

    @PostMapping("/addImport2")
    public Result addImport2(@RequestBody NodeTwo nodeTwo){
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(nodeTwo));
        taskService.addImport2(nodeTwo);
        Result result=Result.success();
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }




    /*
     * 保存配置
     * 参数: NodeTwo 对象
     * 请求方法:post
     * */

    @PostMapping("/addImport3")
    public Result addImport3(@RequestBody NodeThree nodeThree){
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(nodeThree));
         taskService.addImport3(nodeThree);
        Result result=Result.success();
        log.info("功能名称，输入表1添加，请求URI：{}，请求方式：{}，请求参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    /*
     * 展示所有配置列表
     * */
    @PostMapping("/taskList")
    public Result<List<NodeThree>> taskList(){
        log.info("功能名称，配置列表，请求URI：{}，请求方式：{}",request.getRequestURI(),request.getMethod());
        List<NodeThree> list = taskService.taskList();
        Result<List<NodeThree>> success = Result.success(list);
        log.info("功能名称，配置列表，请求URI：{}，请求方式：{}，响应参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(success));
        return success;
    }


    /*
     * 联查信息V1
     * */
    @PostMapping("/JoinList/{nodeOneDatatable}/{nodeTwoDatatable}/{nodeOneField}/{nodeTwoField}/{nodeThreeWay}")
    public Result<List<NodeThree>> JoinList(@PathVariable String nodeOneDatatable,@PathVariable String nodeTwoDatatable,@PathVariable String nodeOneField,@PathVariable String nodeTwoField,@PathVariable String nodeThreeWay){
        log.info("功能名称，配置列表，请求URI：{}，请求方式：{}",request.getRequestURI(),request.getMethod());
        List<NodeThree> list = taskService.JoinList(nodeOneDatatable,nodeTwoDatatable,nodeOneField,nodeTwoField,nodeThreeWay);
        Result<List<NodeThree>> success = Result.success(list);
        log.info("功能名称，配置列表，请求URI：{}，请求方式：{}，响应参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(success));
        return success;
    }


    /*
     * 联查信息v2
     * */
    @PostMapping("/FileList/{nodeThreeId}")
    public Result FileList(@PathVariable  Integer nodeThreeId){
        log.info("功能名称，联查信息，请求URI：{}，请求方式：{}",request.getRequestURI(),request.getMethod());
        NodeThree  threes = taskService.FileList(nodeThreeId);

        Result result = taskService.FileLists(threes.getNodeOneDatatable(), threes.getNodeTwoDatatable(), threes.getNodeOneField(), threes.getNodeTwoField(), threes.getNodeThreeWay(),threes.getNodeFields());

        Result success = Result.success(result);
        log.info("功能名称，联查信息，请求URI：{}，请求方式：{}，响应参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(success));
        return success;
    }



    /*
     * 加载信息
     * */
    @PostMapping("/loading/{nodeThreeId}")
    public Result loading(@PathVariable Integer nodeThreeId ){
        log.info("功能名称，加载信息，请求URI：{}，请求方式：{}",request.getRequestURI(),request.getMethod());
        Result result = taskService.loading(nodeThreeId);
        Result<Result> success = Result.success(result);
        log.info("功能名称，加载信息，请求URI：{}，请求方式：{}，响应参数：{}",request.getRequestURI(),request.getMethod(),JSONObject.toJSONString(success));
        return success;
    }




}

